@@ -16,6 +16,13 @@ factory_dataframe <- function(tab,
 
   out <- tab
 
+  # factor -> character (useful for R<4.0.0)
+  for (i in seq_along(out)) {
+    if (is.factor(out[[i]])) {
+      out[[i]] <- as.character(out[[i]])
+    }
+  }
+
   attr(out, 'align') <- align
   attr(out, 'hrule') <- hrule
   attr(out, 'notes') <- notes
